@@ -1,6 +1,6 @@
 /* arequipad.c - AREQUIPA demon */
  
-/* Written 1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdio.h>
@@ -24,7 +24,7 @@
 
 
 int debug;
-int pretty = A2T_PRETTY | A2T_NAME;
+int pretty = A2T_PRETTY | A2T_NAME | A2T_LOCAL;
 
 
 static void usage(const char *name)
