@@ -1,6 +1,6 @@
 /* io.c - I/O operations */
  
-/* Written 1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1996-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdio.h>
@@ -42,11 +42,12 @@ void open_all(void)
 	diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
     if (ioctl(kernel,AREQUIPA_CTRL,0) < 0)
 	diag(COMPONENT,DIAG_FATAL,"ioctl AREQUIPA_CTRL: %s",strerror(errno));
-    if ((incoming = socket(PF_ATMSVC,SOCK_DGRAM,ATM_AAL5)) < 0)
+    if ((incoming = socket(PF_ATMSVC,SOCK_DGRAM,0)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
     memset(&qos,0,sizeof(qos));
     qos.txtp.traffic_class = qos.rxtp.traffic_class = ATM_ANYCLASS;
 	/* compatible with everything else */
+    qos.aal = ATM_AAL5;
     if (setsockopt(incoming,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"setsockopt SO_ATMQOS: %s",strerror(errno));
     memset(&addr,0,sizeof(addr));
