@@ -230,11 +230,13 @@ static void arp_request(ITF *itf,unsigned long ip)
 }
 
 
-static void inarp_for_itf(int fd,ITF *itf)
+static void inarp_for_itf(VCC *vcc,ITF *itf)
 {
     if (itf->local_ip) {
 	diag(COMPONENT,DIAG_DEBUG,"  on itf %d",itf->number);
-	send_arp(fd,ARPOP_InREQUEST,itf->local_ip,NULL,0,NULL);
+	assert(vcc->entry);
+	send_arp(vcc->fd,ARPOP_InREQUEST,itf->local_ip,NULL,0,
+	  vcc->entry->svc ? vcc->entry->addr : NULL);
     }
 }
 
@@ -247,9 +249,8 @@ static void inarp_request(ENTRY *entry)
     diag(COMPONENT,DIAG_DEBUG,"sending InARP request");
     for (vcc = entry->vccs; vcc; vcc = vcc->next)
 	if (!vcc->connecting)
-	    if (entry->itf) inarp_for_itf(vcc->fd,entry->itf);
-	    else for (itf = itfs; itf; itf = itf->next)
-		    inarp_for_itf(vcc->fd,itf);
+	    if (entry->itf) inarp_for_itf(vcc,entry->itf);
+	    else for (itf = itfs; itf; itf = itf->next) inarp_for_itf(vcc,itf);
 }
 
 
@@ -452,7 +453,7 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
      * If the entry on which we received the update is dangling and we found
      * an entry that already describes that IP address, ...
      */
-    if (vcc && entry && !vcc->entry->itf) {
+    if (entry && vcc && !vcc->entry->itf) {
 	if (!entry->svc) {
 	    diag(COMPONENT,DIAG_ERROR,"attempt to overwrite PVC for IP "
 	      "%d.%d.%d.%d",ipp[0],ipp[1],ipp[2],ipp[3]);
@@ -463,24 +464,23 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
 	free(vcc->entry);
 	vcc->entry = entry;
 	Q_INSERT_HEAD(entry->vccs,vcc);
-	vcc = NULL;
+	assert(!vcc->connecting);
+	if (set_ip(vcc->fd,ip) < 0)
+	    diag(COMPONENT,DIAG_ERROR,"set_ip: %s",strerror(errno));
     }
     /*
-     * If we either found an entry or if the update was received via InARP
-     * (so we can use the entry that already belongs to the VCC), ...
+     * If we still don't have an entry, we try to use the entry that already
+     * belongs to the VCC (InARP), or we create a new one (ARP).
      */
-    if (entry || vcc) {
-	if (!entry) entry = vcc->entry;
-	if (!entry->itf) Q_REMOVE(unknown_incoming,entry);
-    }
-    else {
-	entry = alloc_entry(1);
-	entry->flags = ATF_PUBL;
+    if (!entry)
 	if (vcc) {
-	    vcc->entry = entry;
-	    Q_INSERT_HEAD(entry->vccs,vcc);
+	    entry = vcc->entry;
+	    if (!entry->itf) Q_REMOVE(unknown_incoming,entry);
+	}
+	else {
+	    entry = alloc_entry(1);
+	    entry->flags = ATF_PUBL;
 	}
-    }
     if (entry->state == as_valid && entry->ip == ip && entry->addr &&
       atm_equal(entry->addr,addr,0,0)) return; /* no news */
     STOP_TIMER(entry);
