@@ -26,23 +26,17 @@
 #define COMPONENT "ARPD"
 
 
-#ifdef MEM_DEBUG
-extern int mpr(void);
-extern int mcheck (void (*)(int));
-#endif
-
-
 ITF *itfs = NULL;
 ENTRY *unknown_incoming = NULL;
 int debug;
-int pretty = A2T_PRETTY | A2T_NAME;
+int pretty = A2T_PRETTY | A2T_NAME | A2T_LOCAL;
 int merge = 0;
 
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -l logfile ] [ -m ] [ -n ]\n",
-      name);
+    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -l logfile ] [ -m [ -m ] ] "
+      "[ -n ]\n",name);
     exit(1);
 }
 
@@ -52,10 +46,6 @@ int main(int argc,char **argv)
     const char *dump_dir;
     int c,background;
 
-#ifdef MEM_DEBUG
-    if (getenv("MCHECK")) mcheck(0);
-    if (mpr() < 0) return 1;
-#endif
     set_application("atmarpd");
     set_verbosity(NULL,DIAG_INFO);
     dump_dir = DUMP_DIR;
