@@ -49,9 +49,10 @@ void open_all(void)
 	diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
     if (ioctl(kernel,ATMARPD_CTRL,0) < 0)
 	diag(COMPONENT,DIAG_FATAL,"ioctl ATMARPD_CTRL: %s",strerror(errno));
-    if ((incoming = socket(PF_ATMSVC,SOCK_DGRAM,ATM_AAL5)) < 0)
+    if ((incoming = socket(PF_ATMSVC,SOCK_DGRAM,0)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
     memset(&qos,0,sizeof(qos));
+    qos.aal = ATM_AAL5;
     qos.rxtp.traffic_class = qos.txtp.traffic_class = ATM_ANYCLASS;
     if (setsockopt(incoming,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"setsockopt SO_ATMQOS: %s",strerror(errno));
@@ -220,6 +221,7 @@ static void accept_new(void)
     diag(COMPONENT,DIAG_DEBUG,"Incoming call from %s",buffer);
     if (merge) {
 	ITF *itf;
+
 	for (itf = itfs; itf; itf = itf->next) {
 	    entry = lookup_addr(itf,&addr);
 	    if (entry) {
@@ -249,7 +251,7 @@ int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int timeout)
     int fd,flags;
 
     if (remote->sa_family == AF_ATMSVC && incoming < 0) return -EUNATCH;
-    if ((fd = socket(remote->sa_family,SOCK_DGRAM,ATM_AAL5)) < 0) {
+    if ((fd = socket(remote->sa_family,SOCK_DGRAM,0)) < 0) {
 	diag(COMPONENT,DIAG_ERROR,"socket: %s",strerror(errno));
 	return -errno;
     }
@@ -292,11 +294,13 @@ int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int timeout)
     }
     /* PVC connect never blocks */
     if (connect(fd,remote,remote->sa_family == AF_ATMPVC ?
-      sizeof(struct sockaddr_atmpvc) : sizeof(struct sockaddr_atmsvc)) < 0)
+      sizeof(struct sockaddr_atmpvc) : sizeof(struct sockaddr_atmsvc)) < 0) {
 	if (errno != EINPROGRESS) {
 	    diag(COMPONENT,DIAG_ERROR,"[1]connect: %s",strerror(errno));
 	    return -errno;
 	}
+	return fd;
+    }
     if (ioctl(fd,ATMARP_MKIP,timeout) < 0) {
         diag(COMPONENT,DIAG_ERROR,"ioctl ATMARP_MKIP: %s",strerror(errno));
         (void) do_close(fd);
@@ -332,8 +336,14 @@ static void complete_connect(VCC *vcc)
 	diag(COMPONENT,DIAG_FATAL,"connecting non-connecting VCC 0x%08x",
 	  (unsigned long) vcc);
     memset(&dummy,0,sizeof(dummy));
-    if (!connect(vcc->fd,(struct sockaddr *) &dummy,sizeof(dummy)))
+    if (!connect(vcc->fd,(struct sockaddr *) &dummy,sizeof(dummy))) {
+	if (ioctl(vcc->fd,ATMARP_MKIP,CLIP_DEFAULT_IDLETIMER) < 0) {
+	    diag(COMPONENT,DIAG_ERROR,"ioctl ATMARP_MKIP: %s",strerror(errno));
+	    (void) do_close(vcc->fd);
+	    vcc_failed(vcc);
+	}
 	vcc_connected(vcc);
+    }
     else {
 	diag(COMPONENT,DIAG_INFO,"[2]connect: %s",strerror(errno));
 	(void) do_close(vcc->fd);
