@@ -1,6 +1,6 @@
 /* itf.c - IP interface registry */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdlib.h>
@@ -62,6 +62,7 @@ void itf_up(int number)
     }
     itf->number = number;
     memset(&itf->qos,0,sizeof(struct atm_qos));
+    itf->qos.aal = ATM_AAL5;
     itf->qos.txtp.traffic_class = ATM_UBR;
     itf->qos.txtp.max_sdu = RFC1483LLC_LEN+RFC1626_MTU;
     itf->qos.rxtp = itf->qos.txtp;
