@@ -128,7 +128,7 @@ void update_nsap(int itf, AsnOid *netprefix, AsnOid *esi)
 
   n = 0;
   if (req.length && atm_equal(&addr, &ouraddr[0], ATM_ESA_LEN, 0)) {
-    diag(COMPONENT, DIAG_INFO, "Primary ATM Address did not change");
+    diag(COMPONENT, DIAG_WARN, "Primary ATM Address did not change");
     n = 1;
   }
 
@@ -149,7 +149,7 @@ void update_nsap(int itf, AsnOid *netprefix, AsnOid *esi)
 
 	  atm2text(buffer,MAX_ATM_ADDR_LEN+1,(struct sockaddr *) &addr, A2T_PRETTY);
 
-	  diag(COMPONENT, DIAG_INFO, "Primary ATM Address %s added local", buffer);
+	  diag(COMPONENT, DIAG_WARN, "Primary ATM Address %s added local", buffer);
 	
 	  for (n = 0; n < m/sizeof(addr); n++) {
 
@@ -164,7 +164,7 @@ void update_nsap(int itf, AsnOid *netprefix, AsnOid *esi)
 		  if (ioctl(fd, ATM_ADDADDR, &req) < 0)
 		    diag(COMPONENT, DIAG_ERROR, "ioctl ATM_ADDADDR: %s", strerror(errno));
 	          else	
-		    diag(COMPONENT, DIAG_INFO, "Extra   ATM Address %s added local", buffer);
+		    diag(COMPONENT, DIAG_WARN, "Extra   ATM Address %s added local", buffer);
 
 	  }
   }	     	
@@ -207,6 +207,10 @@ int read_message(int fd, Message *message)
       diag(COMPONENT, DIAG_ERROR, "message decoding error");
       return -1;
     }
+
+  diag(COMPONENT, DIAG_DEBUG, "SNMP message received:");
+  if(get_verbosity(NULL) == DIAG_DEBUG)
+    PrintMessage(get_logfile(), message, 0);
   
   if(message->version != VERSION_1)
     {
@@ -235,12 +239,16 @@ int send_message(int fd, Message *message)
   
   if(!(length = BEncMessage(&buffer, message)))
   {
-    diag(COMPONENT, DIAG_ERROR, "message encoding error\n");
+    diag(COMPONENT, DIAG_ERROR, "message encoding error");
     return -1;
   }
-  
+
   if(write(fd, SBufDataPtr(&buffer), length) != length)
     diag(COMPONENT, DIAG_FATAL, "write: %s", strerror(errno));
+
+  diag(COMPONENT, DIAG_DEBUG, "SNMP message sent:");
+  if(get_verbosity(NULL) == DIAG_DEBUG)
+    PrintMessage(get_logfile(), message, 0);
   
   return 0;
 }
@@ -252,12 +260,13 @@ int open_ilmi(int itf,const char *qos_spec)
     struct atm_qos qos;
     int fd;
 
-    if((fd = socket(PF_ATMPVC, SOCK_DGRAM, ATM_AAL5)) < 0)
+    if((fd = socket(PF_ATMPVC, SOCK_DGRAM, 0)) < 0)
       diag(COMPONENT, DIAG_FATAL, "socket: %s", strerror(errno));
 
     memset(&qos, 0, sizeof(qos));
     qos.rxtp.max_sdu = MAX_ILMI_MSG;
     qos.txtp.max_sdu = MAX_ILMI_MSG;
+    qos.aal = ATM_AAL5;
     if (!qos_spec) qos.rxtp.traffic_class = qos.txtp.traffic_class = ATM_UBR;
     else if (text2qos(qos_spec,&qos,T2Q_DEFAULTS) < 0)
 	    diag(COMPONENT,DIAG_FATAL,"invalid qos: %s",qos_spec);
