@@ -35,7 +35,7 @@
 #define MAX_ATM_ADDR_LEN (2*ATM_ESA_LEN+ATM_E164_LEN+5)
 				/* 4 dots, 1 plus */
 #define MAX_ATM_NAME_LEN 256 /* wild guess */
-#define MAX_ATM_QOS_LEN 111	/* 4+2*(3+3*(7+9)+2)+1 */
+#define MAX_ATM_QOS_LEN 116	/* 5+4+2*(3+3*(7+9)+2)+1 */
 
 
 int text2atm(const char *text,struct sockaddr *addr,int length,int flags);
