@@ -12,10 +12,7 @@
 
 #include "atm.h"
 #include "atmsap.h"
-
-
-#define TRY_OTHER -2
-#define FATAL	  -1 /* must be -1 */
+#include "atmres.h"
 
 
 static int try_pvc(const char *text,struct sockaddr_atmpvc *addr,int flags)
@@ -245,6 +242,8 @@ int text2atm(const char *text,struct sockaddr *addr,int length,int flags)
     }
     if (!(flags & T2A_NAME)) return -1;
     result = try_name(text,addr,length,flags & ~T2A_NAME);
+    if (result == TRY_OTHER && !(flags & T2A_LOCAL))
+	result = ans_byname(text,(struct sockaddr_atmsvc *) addr,length,flags);
     if (result != TRY_OTHER) return result;
     return -1;
 }
