@@ -116,10 +116,7 @@
 #define MOD24(x) ((x) & ((1 << 24)-1))
 #define INC24(v) (v = MOD24(v+1))
 #define INC8(v) (v = (v+1) & 255)
-#define NORMALIZE(x,b) ( \
-    (b) < (1 << 23) ? \
-      (x) < (b)+(1 << 23) ? (x)+(1 << 24) : x : \
-      (x) < (b)-(1 << 23) ? (x)+(1 << 24) : x)
+#define NORMALIZE(x,b) (((x)-(b)) & 0xffffff)
 #define NORM_RX(v) NORMALIZE((v),dsc->vr_r)
 #define NORM_TX(v) NORMALIZE((v),dsc->vt_a)
 
