@@ -24,8 +24,7 @@
 const char *state_name[] = { /* formatting aligned with STATE */
 	"<invalid>",	"ss_null",	"ss_listening",	"ss_connecting",
 	"ss_connected",	"ss_indicated",	"ss_accepting",	"ss_zombie",
-	"ss_hold",	"ss_wait_rel",	"ss_wait_close","ss_rel_req",
-	"ss_rel_ind" };
+	"ss_wait_rel",	"ss_wait_close","ss_rel_req",	"ss_rel_ind" };
 
 const char *qs_name[] = {
 	"NULL",		"CALL_INIT",	"<invalid>",	"OUT_PROC",
@@ -39,8 +38,7 @@ const char *as_name[] = { "<invalid>","as_bind","as_connect","as_accept",
 const Q2931_STATE state_map[] = { /* formatting aligned with STATE */
 	qs_null,	qs_null,	qs_null,	qs_call_init,
 	qs_active,	qs_in_proc,	qs_conn_req,	qs_null,
-	qs_active,	qs_rel_req,	qs_null,	qs_rel_req,
-	qs_rel_ind };
+	qs_rel_req,	qs_null,	qs_rel_req,	qs_rel_ind };
 
 const PARTY_STATE eps_map[] = {
 	ps_null,	ps_add_init,	ps_null,	ps_add_init,	/* 0 */
