@@ -1,6 +1,6 @@
 /* write.c - send AAL5 PDU */
 
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -28,7 +28,7 @@ int main(int argc,char **argv)
     int s,size,offset;
 
     if (argc != 3 && argc != 4) usage(argv[0]);
-    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,ATM_AAL5)) < 0) {
+    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,0)) < 0) {
 	perror("socket");
 	return 1;
     }
@@ -37,6 +37,7 @@ int main(int argc,char **argv)
 	usage(argv[0]);
     offset = argc == 3 ? 0 : atoi(argv[3]);
     memset(&qos,0,sizeof(qos));
+    qos.aal = ATM_AAL5;
     qos.txtp.traffic_class = ATM_UBR;
     qos.txtp.max_sdu = strlen(argv[2])-offset;
     if (setsockopt(s,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0) {
